==> zio-aws-computeoptimizer_2.13-7.21.15.10-sources.jar: zio/aws/computeoptimizer/model/LicenseRecommendationFilter.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.computeoptimizer.model.primitives.FilterValue
import scala.jdk.CollectionConverters._
final case class LicenseRecommendationFilter(
    name: Optional[
      zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
    ] = Optional.Absent,
    values: Optional[Iterable[FilterValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter = {
    import LicenseRecommendationFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter
      .builder()
      .optionallyWith(name.map(value => value.unwrap))(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            FilterValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.LicenseRecommendationFilter.ReadOnly =
    zio.aws.computeoptimizer.model.LicenseRecommendationFilter
      .wrap(buildAwsValue())
}
object LicenseRecommendationFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.computeoptimizer.model.LicenseRecommendationFilter =
      zio.aws.computeoptimizer.model.LicenseRecommendationFilter(
        name.map(value => value),
        values.map(value => value)
      )
    def name: Optional[
      zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
    ]
    def values: Optional[List[FilterValue]]
    def getName: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
    ] = AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[FilterValue]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter
  ) extends zio.aws.computeoptimizer.model.LicenseRecommendationFilter.ReadOnly {
    override val name: Optional[
      zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value =>
        zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
          .wrap(value)
      )
    override val values: Optional[List[FilterValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.FilterValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter
  ): zio.aws.computeoptimizer.model.LicenseRecommendationFilter.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-computeoptimizer_3-7.21.15.3-sources.jar: zio/aws/computeoptimizer/model/LicenseRecommendationFilter.scala <==
package zio.aws.computeoptimizer.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.computeoptimizer.model.primitives.FilterValue
import scala.jdk.CollectionConverters.*
final case class LicenseRecommendationFilter(
    name: Optional[
      zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
    ] = Optional.Absent,
    values: Optional[Iterable[FilterValue]] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter = {
    import LicenseRecommendationFilter.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter
      .builder()
      .optionallyWith(name.map(value => value.unwrap))(_.name)
      .optionallyWith(
        values.map(value =>
          value.map { item =>
            FilterValue.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.values)
      .build()
  }
  def asReadOnly
      : zio.aws.computeoptimizer.model.LicenseRecommendationFilter.ReadOnly =
    zio.aws.computeoptimizer.model.LicenseRecommendationFilter
      .wrap(buildAwsValue())
}
object LicenseRecommendationFilter {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.computeoptimizer.model.LicenseRecommendationFilter =
      zio.aws.computeoptimizer.model.LicenseRecommendationFilter(
        name.map(value => value),
        values.map(value => value)
      )
    def name: Optional[
      zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
    ]
    def values: Optional[List[FilterValue]]
    def getName: ZIO[
      Any,
      AwsError,
      zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
    ] = AwsError.unwrapOptionField("name", name)
    def getValues: ZIO[Any, AwsError, List[FilterValue]] =
      AwsError.unwrapOptionField("values", values)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter
  ) extends zio.aws.computeoptimizer.model.LicenseRecommendationFilter.ReadOnly {
    override val name: Optional[
      zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.name())
      .map(value =>
        zio.aws.computeoptimizer.model.LicenseRecommendationFilterName
          .wrap(value)
      )
    override val values: Optional[List[FilterValue]] = zio.aws.core.internal
      .optionalFromNullable(impl.values())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.computeoptimizer.model.primitives.FilterValue(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.computeoptimizer.model.LicenseRecommendationFilter
  ): zio.aws.computeoptimizer.model.LicenseRecommendationFilter.ReadOnly =
    new Wrapper(impl)
}
